import * as z from 'zod';

const fileSchema = z.instanceof(File, { message: 'Required' });

export const paradontiteType = z.enum(['Si', 'No', 'Non lo so'], {
  message: "Seleziona un'opzione.",
});
export const anniType = z.enum(['18-29', '30-39', '40-59', '60+'], {
  message: "Seleziona un'opzione.",
});
export const siNoType = z.enum(['Si', 'No'], {
  message: "Seleziona un'opzione.",
});
export const contattatoType = z.enum(['Whatsapp', 'Telefono', 'Email']);

export const FormSchema = z
  .object({
    parodontite: paradontiteType,
    anni: anniType,
    dentistaVisitaItalia: siNoType,
    panaromicaDentale: siNoType,
    panoramica: fileSchema.optional().nullable(),
    nome: z.string().min(2, 'Il nome deve avere almeno 2 caratteri.'),
    email: z.string().email(),
    telefono: z.string(),
    tuaDomanda: z.string().optional(),
    contattato: z.array(contattatoType).refine((value) => value.some((item) => item), {
      message: 'Devi selezionare almeno un elemento.',
    }),
  })
  .superRefine((data, ctx) => {
    if (data.panaromicaDentale === 'Si') {
      if (data.panoramica == null) {
        ctx.addIssue({
          code: z.ZodIssueCode.custom,
          message: 'Per favore aggiungi la foto panoramica.',
          path: ['panoramica'],
        });
      }
    } else if (data.panaromicaDentale === 'No') {
      if (data.panoramica != null) {
        ctx.addIssue({
          code: z.ZodIssueCode.custom,
          message: "Non è possibile aggiungere la foto panoramica se si seleziona 'No'.",
          path: ['panoramica'],
        });
      }
    }
  });
